netapp_ontap.models.oracle_on_san API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.oracle_on_san`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class OracleOnSanSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the OracleOnSan object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `archive_log GET POST PATCH`

    The archive_log field of the oracle_on_san.

  `db GET POST PATCH`

    The db field of the oracle_on_san.

  `igroup_name GET POST PATCH`

    The name of the initiator group through which the contents of this application will be accessed. Modification of this parameter is a disruptive operation. All LUNs in the application component will be unmapped from the current igroup and re-mapped to the new igroup.

  `new_igroups POST PATCH`

    The list of initiator groups to create.

  `ora_home GET POST PATCH`

    The ora_home field of the oracle_on_san.

  `os_type GET POST`

    The name of the host OS running the application.

    Valid choices:

    - aix
    - hpux
    - hyper_v
    - linux
    - solaris
    - solaris_efi
    - vmware
    - windows
    - windows_2008
    - windows_gpt
    - xen
  `protection_type GET POST PATCH`

    The protection_type field of the oracle_on_san.

  `redo_log GET POST PATCH`

    The redo_log field of the oracle_on_san.